@@ -80,7 +80,7 @@ var (
 )
 
 // knownPrefixedFiles is a set of known filenames with the .chezmoi prefix.
-var knownPrefixedFiles = newStringSet(
+var knownPrefixedFiles = newSet(
 	Prefix+".json"+TemplateSuffix,
 	Prefix+".toml"+TemplateSuffix,
 	Prefix+".yaml"+TemplateSuffix,
@@ -97,14 +97,14 @@ var knownPrefixedFiles = newStringSet(
 )
 
 // knownPrefixedDirs is a set of known dirnames with the .chezmoi prefix.
-var knownPrefixedDirs = newStringSet(
+var knownPrefixedDirs = newSet(
 	scriptsDirName,
 	templatesDirName,
 )
 
 // knownTargetFiles is a set of known target files that should not be managed
 // directly.
-var knownTargetFiles = newStringSet(
+var knownTargetFiles = newSet(
 	"chezmoi.json",
 	"chezmoi.toml",
 	"chezmoi.yaml",
@@ -203,7 +203,7 @@ func etcHostnameFQDNHostname(fileSystem vfs.FS) (string, error) {
 	s := bufio.NewScanner(bytes.NewReader(contents))
 	for s.Scan() {
 		text := s.Text()
-		text, _, _ = CutString(text, "#")
+		text, _, _ = strings.Cut(text, "#")
 		if hostname := strings.TrimSpace(text); hostname != "" {
 			return hostname, nil
 		}
@@ -241,7 +241,7 @@ func etcHostsFQDNHostname(fileSystem vfs.FS) (string, error) {
 	for s.Scan() {
 		text := s.Text()
 		text = strings.TrimSpace(text)
-		text, _, _ = CutString(text, "#")
+		text, _, _ = strings.Cut(text, "#")
 		fields := whitespaceRx.Split(text, -1)
 		if len(fields) >= 2 && fields[0] == "127.0.1.1" {
 			return fields[1], nil
