@@ -23,16 +23,6 @@ func (s *RealSystem) Glob(pattern string) ([]string, error) {
 	return doublestar.Glob(s.UnderlyingFS(), filepath.ToSlash(pattern))
 }
 
-// IdempotentCmdCombinedOutput implements System.IdempotentCmdCombinedOutput.
-func (s *RealSystem) IdempotentCmdCombinedOutput(cmd *exec.Cmd) ([]byte, error) {
-	return chezmoilog.LogCmdCombinedOutput(cmd)
-}
-
-// IdempotentCmdOutput implements System.IdempotentCmdOutput.
-func (s *RealSystem) IdempotentCmdOutput(cmd *exec.Cmd) ([]byte, error) {
-	return chezmoilog.LogCmdOutput(cmd)
-}
-
 // Link implements System.Link.
 func (s *RealSystem) Link(oldname, newname AbsPath) error {
 	return s.fileSystem.Link(oldname.String(), newname.String())
@@ -87,11 +77,6 @@ func (s *RealSystem) RunCmd(cmd *exec.Cmd) error {
 	return chezmoilog.LogCmdRun(cmd)
 }
 
-// RunIdempotentCmd implements System.RunIdempotentCmd.
-func (s *RealSystem) RunIdempotentCmd(cmd *exec.Cmd) error {
-	return chezmoilog.LogCmdRun(cmd)
-}
-
 // RunScript implements System.RunScript.
 func (s *RealSystem) RunScript(scriptname RelPath, dir AbsPath, data []byte, interpreter *Interpreter) (err error) {
 	// Create the script temporary directory, if needed.
