@@ -1,6 +1,7 @@
 package cmd
 
 import (
+	"runtime"
 	"testing"
 
 	"github.com/stretchr/testify/assert"
@@ -111,10 +112,10 @@ func TestGuessDotfilesRepoURL(t *testing.T) {
 }
 
 func TestIssue2137(t *testing.T) {
-	chezmoitest.WithTestFS(t, map[string]interface{}{
-		"/home/user/.local/share/chezmoi": map[string]interface{}{
+	chezmoitest.WithTestFS(t, map[string]any{
+		"/home/user/.local/share/chezmoi": map[string]any{
 			".chezmoiversion": "3.0.0",
-			".git": map[string]interface{}{
+			".git": map[string]any{
 				".keep": nil,
 			},
 		},
@@ -124,3 +125,22 @@ func TestIssue2137(t *testing.T) {
 		require.ErrorAs(t, err, &tooOldError)
 	})
 }
+
+func TestIssue2283(t *testing.T) {
+	if runtime.GOOS == "windows" {
+		t.Skip("skipping UNIX test on Windows")
+	}
+	chezmoitest.WithTestFS(t, map[string]any{
+		"/home/user/.local/share/chezmoi": map[string]any{
+			".chezmoiroot": "home",
+			"home": map[string]any{
+				".chezmoi.yaml.tmpl": "sourceDir: {{ .chezmoi.sourceDir }}\n",
+			},
+		},
+	}, func(fileSystem vfs.FS) {
+		require.NoError(t, newTestConfig(t, fileSystem).execute([]string{"init"}))
+		data, err := fileSystem.ReadFile("/home/user/.config/chezmoi/chezmoi.yaml")
+		require.NoError(t, err)
+		assert.Equal(t, "sourceDir: /home/user/.local/share/chezmoi/home\n", string(data))
+	})
+}
