@@ -59,6 +59,7 @@ func TestScript(t *testing.T) {
 			"expandenv":      cmdExpandEnv,
 			"httpd":          cmdHTTPD,
 			"issymlink":      cmdIsSymlink,
+			"lexists":        cmdLExists,
 			"mkfile":         cmdMkFile,
 			"mkageconfig":    cmdMkAgeConfig,
 			"mkgitconfig":    cmdMkGitConfig,
@@ -95,7 +96,8 @@ func TestScript(t *testing.T) {
 			}
 			return false, fmt.Errorf("%s: unknown condition", cond)
 		},
-		Setup: setup,
+		RequireExplicitExec: true,
+		Setup:               setup,
 	})
 }
 
@@ -221,7 +223,7 @@ func cmdHTTPD(ts *testscript.TestScript, neg bool, args []string) {
 	ts.Setenv("HTTPD_URL", server.URL)
 }
 
-// cmdIsSymlink returns true if all of its arguments are symlinks.
+// cmdIsSymlink succeeds if all of its arguments are symlinks.
 func cmdIsSymlink(ts *testscript.TestScript, neg bool, args []string) {
 	for _, arg := range args {
 		filename := ts.MkAbs(arg)
@@ -238,6 +240,23 @@ func cmdIsSymlink(ts *testscript.TestScript, neg bool, args []string) {
 	}
 }
 
+// cmdLExists succeeds if all if its arguments exist, without following symlinks.
+func cmdLExists(ts *testscript.TestScript, neg bool, args []string) {
+	if len(args) == 0 {
+		ts.Fatalf("usage: exists file...")
+	}
+
+	for _, arg := range args {
+		filename := ts.MkAbs(arg)
+		switch _, err := os.Lstat(filename); {
+		case err == nil && neg:
+			ts.Fatalf("%s unexpectedly exists", filename)
+		case errors.Is(err, fs.ErrNotExist) && !neg:
+			ts.Fatalf("%s does not exist", filename)
+		}
+	}
+}
+
 // cmdMkFile creates empty files.
 func cmdMkFile(ts *testscript.TestScript, neg bool, args []string) {
 	if neg {
@@ -386,12 +405,12 @@ func cmdMkHomeDir(ts *testscript.TestScript, neg bool, args []string) {
 	workDir := ts.Getenv("WORK")
 	relPath, err := filepath.Rel(workDir, path)
 	ts.Check(err)
-	if err := vfst.NewBuilder().Build(vfs.NewPathFS(vfs.OSFS, workDir), map[string]interface{}{
-		relPath: map[string]interface{}{
+	if err := vfst.NewBuilder().Build(vfs.NewPathFS(vfs.OSFS, workDir), map[string]any{
+		relPath: map[string]any{
 			".create": "# contents of .create\n",
-			".dir": map[string]interface{}{
+			".dir": map[string]any{
 				"file": "# contents of .dir/file\n",
-				"subdir": map[string]interface{}{
+				"subdir": map[string]any{
 					"file": "# contents of .dir/subdir/file\n",
 				},
 			},
@@ -432,12 +451,12 @@ func cmdMkSourceDir(ts *testscript.TestScript, neg bool, args []string) {
 	workDir := ts.Getenv("WORK")
 	relPath, err := filepath.Rel(workDir, sourceDir)
 	ts.Check(err)
-	err = vfst.NewBuilder().Build(vfs.NewPathFS(vfs.OSFS, workDir), map[string]interface{}{
-		relPath: map[string]interface{}{
+	err = vfst.NewBuilder().Build(vfs.NewPathFS(vfs.OSFS, workDir), map[string]any{
+		relPath: map[string]any{
 			"create_dot_create": "# contents of .create\n",
-			"dot_dir": map[string]interface{}{
+			"dot_dir": map[string]any{
 				"file": "# contents of .dir/file\n",
-				"exact_subdir": map[string]interface{}{
+				"exact_subdir": map[string]any{
 					"file": "# contents of .dir/subdir/file\n",
 				},
 			},
@@ -634,10 +653,10 @@ func setup(env *testscript.Env) error {
 		env.Setenv("SHELL", filepath.Join(binDir, "shell"))
 	}
 
-	root := make(map[string]interface{})
+	root := make(map[string]any)
 	switch runtime.GOOS {
 	case "windows":
-		root["/bin"] = map[string]interface{}{
+		root["/bin"] = map[string]any{
 			// editor.cmd is a non-interactive script that appends "# edited\n"
 			// to the end of each file and creates an empty .edited file in each
 			// directory.
@@ -656,7 +675,7 @@ func setup(env *testscript.Env) error {
 			},
 		}
 	default:
-		root["/bin"] = map[string]interface{}{
+		root["/bin"] = map[string]any{
 			// editor is a non-interactive script that appends "# edited\n" to
 			// the end of each file and creates an empty .edited file in each
 			// directory.
