@@ -10,7 +10,6 @@ import (
 
 	"github.com/coreos/go-semver/semver"
 
-	"github.com/twpayne/chezmoi/v2/pkg/chezmoi"
 	"github.com/twpayne/chezmoi/v2/pkg/chezmoilog"
 )
 
@@ -42,18 +41,18 @@ type onepasswordArgs struct {
 
 type onepasswordItemV1 struct {
 	Details struct {
-		Fields   []map[string]interface{} `json:"fields"`
+		Fields   []map[string]any `json:"fields"`
 		Sections []struct {
-			Fields []map[string]interface{} `json:"fields,omitempty"`
+			Fields []map[string]any `json:"fields,omitempty"`
 		} `json:"sections"`
 	} `json:"details"`
 }
 
 type onepasswordItemV2 struct {
-	Fields []map[string]interface{} `json:"fields"`
+	Fields []map[string]any `json:"fields"`
 }
 
-func (c *Config) onepasswordTemplateFunc(userArgs ...string) map[string]interface{} {
+func (c *Config) onepasswordTemplateFunc(userArgs ...string) map[string]any {
 	version, err := c.onepasswordVersion()
 	if err != nil {
 		panic(err)
@@ -81,14 +80,14 @@ func (c *Config) onepasswordTemplateFunc(userArgs ...string) map[string]interfac
 		panic(err)
 	}
 
-	var data map[string]interface{}
+	var data map[string]any
 	if err := json.Unmarshal(output, &data); err != nil {
 		panic(newParseCmdOutputError(c.Onepassword.Command, args.args, output, err))
 	}
 	return data
 }
 
-func (c *Config) onepasswordDetailsFieldsTemplateFunc(userArgs ...string) map[string]interface{} {
+func (c *Config) onepasswordDetailsFieldsTemplateFunc(userArgs ...string) map[string]any {
 	version, err := c.onepasswordVersion()
 	if err != nil {
 		panic(err)
@@ -101,7 +100,7 @@ func (c *Config) onepasswordDetailsFieldsTemplateFunc(userArgs ...string) map[st
 			panic(err)
 		}
 
-		result := make(map[string]interface{})
+		result := make(map[string]any)
 		for _, field := range item.Details.Fields {
 			if designation, ok := field["designation"].(string); ok {
 				result[designation] = field
@@ -115,7 +114,7 @@ func (c *Config) onepasswordDetailsFieldsTemplateFunc(userArgs ...string) map[st
 			panic(err)
 		}
 
-		result := make(map[string]interface{})
+		result := make(map[string]any)
 		for _, field := range item.Fields {
 			if _, ok := field["section"]; ok {
 				continue
@@ -168,7 +167,7 @@ func (c *Config) onepasswordDocumentTemplateFunc(userArgs ...string) string {
 	return string(output)
 }
 
-func (c *Config) onepasswordItemFieldsTemplateFunc(userArgs ...string) map[string]interface{} {
+func (c *Config) onepasswordItemFieldsTemplateFunc(userArgs ...string) map[string]any {
 	version, err := c.onepasswordVersion()
 	if err != nil {
 		panic(err)
@@ -181,7 +180,7 @@ func (c *Config) onepasswordItemFieldsTemplateFunc(userArgs ...string) map[strin
 			panic(err)
 		}
 
-		result := make(map[string]interface{})
+		result := make(map[string]any)
 		for _, section := range item.Details.Sections {
 			for _, field := range section.Fields {
 				if t, ok := field["t"].(string); ok {
@@ -197,7 +196,7 @@ func (c *Config) onepasswordItemFieldsTemplateFunc(userArgs ...string) map[strin
 			panic(err)
 		}
 
-		result := make(map[string]interface{})
+		result := make(map[string]any)
 		for _, field := range item.Fields {
 			if _, ok := field["section"]; !ok {
 				continue
@@ -439,7 +438,7 @@ func newOnepasswordArgs(baseArgs, userArgs []string) (*onepasswordArgs, error) {
 func onepasswordUniqueSessionToken(environ []string) string {
 	var token string
 	for _, env := range environ {
-		key, value, found := chezmoi.CutString(env, "=")
+		key, value, found := strings.Cut(env, "=")
 		if found && strings.HasPrefix(key, "OP_SESSION_") {
 			if token != "" {
 				return ""
